TaskExecutionContext class
Constructors
- TaskExecutionContext({required ExecutableTask task, required Duration timeBlockLimit, required DateTime started, required PrecisionStopwatch stopwatch})
Properties
- backing ↔ bool
-
getter/setter pair
- elapsedTime → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTimeRemaining → bool
-
no setter
- lastBack ↔ Duration?
-
getter/setter pair
- remainingTime → Duration
-
no setter
- running ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- started → DateTime
-
final
- stopwatch → PrecisionStopwatch
-
final
- task → ExecutableTask
-
final
- timeBlockLimit → Duration
-
final
Methods
-
backoff(
) → void -
complete(
) → void -
fail(
String err) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited