TaskExecutor<T extends ExecutableTask> class

Constructors

TaskExecutor({required String typeId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
final

Methods

deserialize(Map<String, dynamic> data) → T
isCompatible(ExecutableTask task) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited