TaskManager class
Constructors
-
TaskManager({required String queue, required String endpointUrl, required List<
TaskExecutor< executors, Duration executionBlockTime = const Duration(minutes: 5)})ExecutableTask> > -
const
Properties
- endpointUrl → String
-
I.e. https://some-server-1234.us-regionX.run.app/event/executeJob
You will need to handle it with Router()..taskManager(THIS OBJECT)
where the router is handling /event. This will add the /executeJob
or whatever your trailing slash is as a new post request route to this router
final
- executionBlockTime → Duration
-
final
-
executors
→ List<
TaskExecutor< ExecutableTask> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- queue → String
-
I.e. barbequeue
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executorForTask(
ExecutableTask task) → TaskExecutor< ExecutableTask> ? -
handleTaskJob(
Request request) → Future< Response> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
schedule(
ExecutableTask task, {int? lbms, Duration delay = const Duration(seconds: 1)}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited