endpointUrl property
I.e. https://some-server-1234.us-regionX.run.app/event/executeJob You will need to handle it with Router()..taskManager(THIS OBJECT) where the router is handling /event. This will add the /executeJob or whatever your trailing slash is as a new post request route to this router
Implementation
final String endpointUrl;